@@ -1,4 +1,4 @@
-# Copyright 2020 Splunk Inc.
+# Copyright Splunk Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,4 +19,10 @@ application to capture and report distributed traces to Splunk APM.
 https://github.com/signalfx/splunk-otel-python
 """
 
-from .version import __version__
+from .defaults import _set_otel_defaults
+
+_set_otel_defaults()
+
+# pylint: disable=wrong-import-position
+from .tracing import start_tracing  # noqa: E402
+from .version import __version__  # noqa: E402
