@@ -17,14 +17,16 @@ import os
 import sys
 from typing import Any, Collection, Dict, Optional, Union
 
-from opentelemetry import environment_variables as otel_env_vars
 from opentelemetry import trace
+from opentelemetry.instrumentation.environment_variables import (
+    OTEL_PYTHON_DISABLED_INSTRUMENTATIONS,
+)
 from opentelemetry.instrumentation.propagators import set_global_response_propagator
 from opentelemetry.sdk.trace import TracerProvider
 from opentelemetry.sdk.trace.export import BatchSpanProcessor
 from pkg_resources import iter_entry_points
 
-from splunk_otel.options import Options, _SpanExporterFactory
+from splunk_otel.options import _Options, _SpanExporterFactory
 
 logger = logging.getLogger(__file__)
 logger.setLevel(logging.INFO)
@@ -32,44 +34,44 @@ logger.setLevel(logging.INFO)
 
 def start_tracing(
     service_name: Optional[str] = None,
-    exporters: Optional[Collection[_SpanExporterFactory]] = None,
+    span_exporter_factories: Optional[Collection[_SpanExporterFactory]] = None,
     access_token: Optional[str] = None,
-    max_attr_length: Optional[int] = None,
     resource_attributes: Optional[Dict[str, Union[str, bool, int, float]]] = None,
     trace_response_header_enabled: Optional[bool] = None,
-) -> None:
+) -> TracerProvider:
     enabled = os.environ.get("OTEL_TRACE_ENABLED", True)
     if not _is_truthy(enabled):
         logger.info("tracing has been disabled with OTEL_TRACE_ENABLED=%s", enabled)
-        return
+        return None
 
-    options = Options(
+    options = _Options(
         service_name,
-        exporters,
+        span_exporter_factories,
         access_token,
-        max_attr_length,
         resource_attributes,
         trace_response_header_enabled,
     )
     try:
-        _configure_tracing(options)
+        provider = _configure_tracing(options)
         _load_instrumentors()
+        return provider
     except Exception:  # pylint:disable=broad-except
         sys.exit(2)
 
 
-def _configure_tracing(options: Options) -> None:
+def _configure_tracing(options: _Options) -> TracerProvider:
     provider = TracerProvider(resource=options.resource)
     set_global_response_propagator(options.response_propagator)  # type: ignore
     trace.set_tracer_provider(provider)
     for factory in options.span_exporter_factories:
         provider.add_span_processor(BatchSpanProcessor(factory(options)))
+    return provider
 
 
 def _load_instrumentors() -> None:
-    package_to_exclude = os.environ.get(
-        otel_env_vars.OTEL_PYTHON_DISABLED_INSTRUMENTATIONS, ""
-    ).split(",")
+    package_to_exclude = os.environ.get(OTEL_PYTHON_DISABLED_INSTRUMENTATIONS, "").split(
+        ","
+    )
     package_to_exclude = [p.strip() for p in package_to_exclude]
 
     for entry_point in iter_entry_points("opentelemetry_instrumentor"):
